@@ -144,7 +144,7 @@ def make_trc(config, Q, keypoints_names, f_range):
     Q = zup2yup(Q)
     
     #Add Frame# and Time columns
-    Q.index = np.array(range(f_range[0], f_range[1])) + 1
+    Q.index = np.array(range(f_range[0]-f_range[0], f_range[1]-f_range[0])) + 1
     Q.insert(0, 't', Q.index / frame_rate)
 
     #Write file
@@ -213,6 +213,8 @@ def triangulation_from_best_cameras(config, coords_2D_kpt, projection_matrices):
     2. Tries all possible triangulations
     3. Chooses the one with smallest reprojection error
     If error too big, take off one more camera.
+        If then below threshold, retain result.
+        If better but still too big, take off one more camera.
     
     INPUTS:
     - a Config.toml file
@@ -357,10 +359,10 @@ def triangulate_all(config):
     project_dir = config.get('project').get('project_dir')
     if project_dir == '': project_dir = os.getcwd()
     calib_folder_name = config.get('project').get('calib_folder_name')
-    openpose_model = config.get('pose-2d').get('openpose_model')
+    pose_model = config.get('pose-2d').get('pose_model')
     pose_folder_name = config.get('project').get('pose_folder_name')
     json_folder_extension =  config.get('project').get('pose_json_folder_extension')
-    frames_range = config.get('project').get('frames_range')
+    frame_range = config.get('project').get('frame_range')
     likelihood_threshold = config.get('3d-triangulation').get('likelihood_threshold')
     interpolation_kind = config.get('3d-triangulation').get('interpolation')
     pose_dir = os.path.join(project_dir, pose_folder_name)
@@ -373,7 +375,7 @@ def triangulate_all(config):
     P = computeP(calib_file)
     
     # Retrieve keypoints from model
-    model = eval(openpose_model)
+    model = eval(pose_model)
     keypoints_ids = [node.id for _, _, node in RenderTree(model) if node.id!=None]
     keypoints_names = [node.name for _, _, node in RenderTree(model) if node.id!=None]
     keypoints_idx = list(range(len(keypoints_ids)))
@@ -392,8 +394,8 @@ def triangulate_all(config):
         json_tracked_files = [[os.path.join(pose_dir, j_dir, j_file) for j_file in json_files_names[j]] for j, j_dir in enumerate(json_dirs_names)]
     
     # Triangulation
-    f_range = [[0,min([len(j) for j in json_files_names])] if frames_range==[] else frames_range][0]
-
+    f_range = [[0,min([len(j) for j in json_files_names])] if frame_range==[] else [i - min(frame_range) for i in frame_range]][0]
+    
     n_cams = len(json_dirs_names)
     Q_tot, error_tot, nb_cams_excluded_tot = [], [], []
     for f in tqdm(range(*f_range)):
@@ -431,7 +433,7 @@ def triangulate_all(config):
     Q_tot = Q_tot.apply(interpolate_nans, axis=0, args = [interpolation_kind])
    
     # Create TRC file
-    trc_path = make_trc(config, Q_tot, keypoints_names, f_range)
+    trc_path = make_trc(config, Q_tot, keypoints_names, frame_range)
     
     # Recap message
     recap_triangulate(config, error_tot, nb_cams_excluded_tot, keypoints_names, trc_path)
